@@ -93,6 +93,10 @@ typedef struct sMarkAdConfig {
     bool fullDecode                = false;    //!< <b>true:</b> decode all video frames <br>
     //!< <b>false:</b> decode only iFrames
     //!<
+    bool forcedFullDecode          = false;    //!< true: full decoding was forced bacause of video codec
+    //!<
+    bool smartEncode               = false;    //!< <b>true:</b> re-encode only frames arounf cut position <br>
+    //!<
     bool fullEncode                = false;    //!< <b>true:</b> full re-encode all frames, cut on all frame types <br>
     //!< <b>false:</b> copy frames without re-encode, cut on iframe position
     //!<
@@ -163,7 +167,7 @@ public:
         criteria                  = nullptr;
         startA                    = origin.startA;
         stopA                     = origin.stopA;
-        frameCheckStart           = origin.frameCheckStart;
+        packetCheckStart          = origin.packetCheckStart;
         ptitle                    = title;
         directory                 = origin.directory;
         video                     = nullptr;
@@ -186,9 +190,10 @@ public:
         detectLogoStopStart       = origin.detectLogoStopStart;
         doneCheckStop             = origin.doneCheckStop;
         doneCheckStart            = origin.doneCheckStart;
-        frameCheckStop            = origin.frameCheckStop;
+        packetEndPart             = origin.packetEndPart;
+        packetCheckStop           = origin.packetCheckStop;
         extractLogo               = nullptr;
-        sleepcnt = origin.sleepcnt;
+        sleepcnt                  = origin.sleepcnt;
     };
 
     /**
@@ -201,7 +206,7 @@ public:
         criteria                  = nullptr;
         startA                    = origin->startA;
         stopA                     = origin->stopA;
-        frameCheckStart           = origin->frameCheckStart;
+        packetCheckStart          = origin->packetCheckStart;
         ptitle                    = title;
         directory                 = origin->directory;
         video                     = nullptr;
@@ -225,7 +230,8 @@ public:
         detectLogoStopStart       = origin->detectLogoStopStart;
         doneCheckStop             = origin->doneCheckStop;
         doneCheckStart            = origin->doneCheckStart;
-        frameCheckStop            = origin->frameCheckStop;
+        packetCheckStop           = origin->packetCheckStop;
+        packetEndPart             = origin->packetEndPart;
         extractLogo               = origin->extractLogo;
         return *this;
     }
@@ -529,9 +535,11 @@ private:
     //!<
     int stopA                        = 0;        //!< assumed end frame position
     //!<
-    int frameCheckStart              = 0;        //!< frame number to check for start mark
+    int packetCheckStart             = 0;        //!< packet number to check for start mark
     //!<
-    int frameCheckStop               = 0;        //!< frame number to check for end mark
+    int packetCheckStop              = 0;        //!< packet number to check for end mark
+    //!<
+    int packetEndPart                = 0;        //!< packet number of start of end part
     //!<
     bool doneCheckStart              = false;    //!< true, if CheckStart() was called
     //!<
@@ -559,5 +567,23 @@ private:
     //!<
     cDetectLogoStopStart *detectLogoStopStart             = nullptr;  //!< pointer to class cDetectLogoStopStart
     //!<
+
+    /**
+     * elapsed time of section
+     */
+    struct sElapsedTime {
+        int markDetection    = 0;    //!< elapsed time in ms for mark detection
+        //!<
+        int markOptimization = 0;    //!< elapsed time in ms for mark optimization
+        //!<
+        int logoSearch       = 0;    //!< elapsed time in ms for initial logo search and extraxtion from cache/recording directory or recording
+        //!<
+        int overlap          = 0;    //!< elapsed time in ms for overlap detection
+        //!<
+        int cut              = 0;    //!< elapsed time in ms for video cut
+        //!<
+        int markPictures     = 0;    //!< elapsed time in ms for debug mark position picture
+        //!<
+    } elapsedTime; //!< elapsed time statistics
 };
 #endif
